Welcome to km3irf's documentation!
===================================

.. note::

   This project is under active development.

Contents
--------

.. toctree::
   :maxdepth: 2

   autoapi/index
   examples
   changelog 
   Code Coverage <http://km3py.pages.km3net.de/km3irf/coverage>

.. include:: ../README.rst

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
